---
feature_story: FS_46_96_59_05
feature_title: plugin `init_control`
feature_status: TEST
---

This feature computes values for the next `data_envelope` as initial `args_context`:

In order to narrow down the search for the next `data_envelope` quickly,
some (`arg_name`, `arg_value`) pairs can be assigned as `ValueSource.init_value`-s into the next `args_context`
by `PluginType.DelegatorPlugin` - see usage of `init_control`.
